#[non_exhaustive]pub struct DiagnosticsBatch {
pub uri: DocumentUri,
pub generation: Generation,
pub diagnostics: Vec<Diagnostic>,
}Expand description
Diagnostics for a single document at a specific engine generation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: DocumentUriThe document the diagnostics apply to.
generation: GenerationThe engine generation at which they were computed.
diagnostics: Vec<Diagnostic>The findings.
Implementations
Sourceimpl DiagnosticsBatch
impl DiagnosticsBatch
Sourcepub fn new(
uri: DocumentUri,
generation: Generation,
diagnostics: Vec<Diagnostic>,
) -> Self
pub fn new( uri: DocumentUri, generation: Generation, diagnostics: Vec<Diagnostic>, ) -> Self
Construct a batch tagging diagnostics for uri at generation.