Dispatcher

Struct Dispatcher 

pub struct Dispatcher { /* private fields */ }
Routes inbound JSON-RPC method calls to async handlers.

Implementations

Source

impl Dispatcher

pub fn new() -> Self

New empty dispatcher.

pub fn register<F, Fut>(&self, method: impl Into<String>, handler: F)
where F: Fn(Value, CancellationToken) -> Fut + Send + Sync + 'static, Fut: Future<Output = HandlerResult> + Send + 'static,

Register a handler for method. Replaces any previously registered handler.

pub async fn dispatch( &self, id: &RequestId, method: &str, params: Value, ) -> Result<HandlerResult, DispatchError>

Dispatch a request. Returns the handler’s result.

The supplied id is used to register a cancellation token so a later $/cancelRequest for the same id can trip the handler.

Errors

Returns DispatchError::UnknownMethod if no handler is registered.

pub fn cancel(&self, id: &RequestId)

Trip the cancellation token for an in-flight request. No-op if unknown.